macro_rules! event_wrapper_test_cases {
($iface_enum:ty, $ufet:ty) => { ... };
}Expand description
Expands to five tests:
into_and_try_from_eventzbus_msg_invalid_interfacezbus_msg_invalid_memberzbus_msg_invalid_member_and_interfacezbus_msg_conversion
The macro takes two arguments:
- The event’s interface enum type.
- Any user facing event type that is wrapped by the interface enum.
Examples
ⓘ
event_wrapper_test_cases!(MouseEvents, AbsEvent);For each of the types, the macro will create a module with the name events_tests_{foo}
where {foo} is the snake case of the ‘interface enum’ name.